@@ -70,7 +70,7 @@ class ImprovedExceptionReporter(ExceptionReporter):
             'exception_value': smart_unicode(self.exc_value, errors='replace'),
             'unicode_hint': unicode_hint,
             'frames': frames,
-            'lastframe': frames[-1],
+            'lastframe': frames and frames[-1] or None,
             'request': self.request,
             'template_info': self.template_info,
             'template_does_not_exist': self.template_does_not_exist,
@@ -83,6 +83,7 @@ class FakeRequest(object):
     META = {}
     COOKIES = {}
     FILES = {}
+    raw_post_data = ''
     url = ''
     
     def __repr__(self):
@@ -127,10 +128,12 @@ TECHNICAL_500_TEMPLATE = """
       <th>Exception Value:</th>
       <td><pre>{{ exception_value|escape }}</pre></td>
     </tr>
+    {% if lastframe %}
     <tr>
       <th>Exception Location:</th>
       <td>{{ lastframe.filename|escape }} in {{ lastframe.function|escape }}, line {{ lastframe.lineno }}</td>
     </tr>
+    {% endif %}
   </table>
 </div>
 {% if unicode_hint %}
